searchData={"items":[{"type":"module","title":"Erlex","doc":"Convert Erlang style structs and error messages to equivalent Elixir.\n\nLexes and parses the Erlang output, then runs through pretty\nprinter.","ref":"Erlex.html"},{"type":"module","title":"Usage - Erlex","doc":"Invoke `Erlex.pretty_print/1` wuth the input string.\n\n```elixir\niex> str = ~S\"('Elixir.Plug.Conn':t(),binary() | atom(),'Elixir.Keyword':t() | map()) -> 'Elixir.Plug.Conn':t()\"\niex> Erlex.pretty_print(str)\n(Plug.Conn.t(), binary() | atom(), Keyword.t() | map()) :: Plug.Conn.t()\n```\n\nWhile the lion's share of the work is done via invoking\n`Erlex.pretty_print/1`, other higher order functions exist for further\nformatting certain messages by running through the Elixir formatter.\nBecause we know the previous example is a type, we can invoke the\n`Erlex.pretty_print_contract/1` function, which would format that\nappropriately for very long lines.\n\n```elixir\niex> str = ~S\"('Elixir.Plug.Conn':t(),binary() | atom(),'Elixir.Keyword':t() | map(), map() | atom(), non_neg_integer(), binary(), binary(), binary(), binary(), binary()) -> 'Elixir.Plug.Conn':t()\"\niex> Erlex.pretty_print_contract(str)\n(\n  Plug.Conn.t(),\n  binary() | atom(),\n  Keyword.t() | map(),\n  map() | atom(),\n  non_neg_integer(),\n  binary(),\n  binary(),\n  binary(),\n  binary(),\n  binary()\n) :: Plug.Conn.t()\n```","ref":"Erlex.html#module-usage"},{"type":"function","title":"Erlex.pretty_print/1","doc":"","ref":"Erlex.html#pretty_print/1"},{"type":"function","title":"Erlex.pretty_print_args/1","doc":"","ref":"Erlex.html#pretty_print_args/1"},{"type":"function","title":"Erlex.pretty_print_contract/1","doc":"","ref":"Erlex.html#pretty_print_contract/1"},{"type":"function","title":"Erlex.pretty_print_contract/3","doc":"","ref":"Erlex.html#pretty_print_contract/3"},{"type":"function","title":"Erlex.pretty_print_infix/1","doc":"","ref":"Erlex.html#pretty_print_infix/1"},{"type":"function","title":"Erlex.pretty_print_pattern/1","doc":"","ref":"Erlex.html#pretty_print_pattern/1"},{"type":"function","title":"Erlex.pretty_print_type/1","doc":"","ref":"Erlex.html#pretty_print_type/1"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\nThis project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).\n\n## [Unreleased]","ref":"changelog.html"},{"type":"extras","title":"Added - Changelog","doc":"- Support for Elixir 1.16: removes new compiler warnings.","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Changelog","doc":"- Parser and lexer modules renamed with `erlex_` prefix to avoid conflict with similarly named modules.","ref":"changelog.html#changed"},{"type":"extras","title":"Fixed - Changelog","doc":"- Lone `_` variables in patterns","ref":"changelog.html#fixed"},{"type":"extras","title":"0.2.6 - 2020-03-09 - Changelog","doc":"","ref":"changelog.html#0-2-6-2020-03-09"},{"type":"extras","title":"Added - Changelog","doc":"- Replace << parsing to fix nested pattern matching binary bugs discovered from Phoenix 1.4.15.","ref":"changelog.html#added"},{"type":"extras","title":"0.2.5 - 2019-09-19 - Changelog","doc":"","ref":"changelog.html#0-2-5-2019-09-19"},{"type":"extras","title":"Added - Changelog","doc":"- Handle Erlang variables better with casing in guards.","ref":"changelog.html#added"},{"type":"extras","title":"0.2.4 - 2019-07-18 - Changelog","doc":"","ref":"changelog.html#0-2-4-2019-07-18"},{"type":"extras","title":"Added - Changelog","doc":"- Handle names in whens more properly.","ref":"changelog.html#added"},{"type":"extras","title":"0.2.3 - 2019-07-16 - Changelog","doc":"","ref":"changelog.html#0-2-3-2019-07-16"},{"type":"extras","title":"Added - Changelog","doc":"- Handle single letter atoms in constracts.","ref":"changelog.html#added"},{"type":"extras","title":"0.2.2 - 2019-06-07 - Changelog","doc":"","ref":"changelog.html#0-2-2-2019-06-07"},{"type":"extras","title":"Added - Changelog","doc":"- Handle pretty printing binary strings better.","ref":"changelog.html#added"},{"type":"extras","title":"0.2.1 - 2019-02-11 - Changelog","doc":"","ref":"changelog.html#0-2-1-2019-02-11"},{"type":"extras","title":"Added - Changelog","doc":"- Handle another struct pretty print.","ref":"changelog.html#added"},{"type":"extras","title":"0.2.0 - 2019-02-01 - Changelog","doc":"","ref":"changelog.html#0-2-0-2019-02-01"},{"type":"extras","title":"Added - Changelog","doc":"- Handle scientific notation.\n- Handle numbered differently, fixes bug.\n- Handle ... contracts.\n- Add another struct pretty print layer.","ref":"changelog.html#added"},{"type":"extras","title":"0.1.6 - 2018-11-06 - Changelog","doc":"","ref":"changelog.html#0-1-6-2018-11-06"},{"type":"extras","title":"Added - Changelog","doc":"- Add ability to pretty print exception struct as Exception.t().","ref":"changelog.html#added"},{"type":"extras","title":"0.1.5 - 2018-09-17 - Changelog","doc":"","ref":"changelog.html#0-1-5-2018-09-17"},{"type":"extras","title":"Added - Changelog","doc":"- Add ability to pretty print numbered named types","ref":"changelog.html#added"},{"type":"extras","title":"0.1.4 - 2018-09-17 - Changelog","doc":"","ref":"changelog.html#0-1-4-2018-09-17"},{"type":"extras","title":"Added - Changelog","doc":"- Add ability to parse whens in specs.","ref":"changelog.html#added"},{"type":"extras","title":"0.1.3 - 2018-09-10 - Changelog","doc":"","ref":"changelog.html#0-1-3-2018-09-10"},{"type":"extras","title":"Added - Changelog","doc":"- Add ability to parse empty tuples\n- Bump ex_doc","ref":"changelog.html#added"},{"type":"extras","title":"0.1.2 - 2018-08-26 - Changelog","doc":"","ref":"changelog.html#0-1-2-2018-08-26"},{"type":"extras","title":"Added - Changelog","doc":"- Add ability to deal with when clauses in contracts","ref":"changelog.html#added"},{"type":"extras","title":"0.1.1 - 2018-08-21 - Changelog","doc":"","ref":"changelog.html#0-1-1-2018-08-21"},{"type":"extras","title":"Added - Changelog","doc":"- Add newline characters in multihead contracts","ref":"changelog.html#added"},{"type":"extras","title":"0.1.0 - 2018-07-22 - Changelog","doc":"","ref":"changelog.html#0-1-0-2018-07-22"},{"type":"extras","title":"Added - Changelog","doc":"- Changelog, CI, docs\n- Initial functionality and tests\n\n[Unreleased]: https://github.com/christhekeele/erlex/compare/v0.2.1...HEAD\n[0.2.0...0.2.1]: https://github.com/christhekeele/erlex/compare/v0.2.0...v0.2.1\n[0.1.6...0.2.0]: https://github.com/christhekeele/erlex/compare/v0.1.6...v0.2.0\n[0.1.5...0.1.6]: https://github.com/christhekeele/erlex/compare/v0.1.5...v0.1.6\n[0.1.4...0.1.5]: https://github.com/christhekeele/erlex/compare/v0.1.4...v0.1.5\n[0.1.3...0.1.4]: https://github.com/christhekeele/erlex/compare/v0.1.3...v0.1.4\n[0.1.2...0.1.3]: https://github.com/christhekeele/erlex/compare/v0.1.2...v0.1.3\n[0.1.1...0.1.2]: https://github.com/christhekeele/erlex/compare/v0.1.1...v0.1.2\n[0.1.0...0.1.1]: https://github.com/christhekeele/erlex/compare/v0.1.0...v0.1.1","ref":"changelog.html#added"},{"type":"extras","title":"Erlex","doc":"# Erlex\n\nConvert Erlang style structs and error messages to equivalent Elixir.\n\nUseful for pretty printing things like Dialyzer errors and Observer\nstate. NOTE: Because this code calls the Elixir formatter, it requires\nElixir 1.6+.\n\n[![Version][hex-pm-version-badge]][hex-pm-versions]\n[![Documentation][docs-badge]][docs]\n[![License][hex-pm-license-badge]][apache-2-license]\n[![Downloads][hex-pm-downloads-badge]][hex-pm-package]\n\n|         👍         |                  [Test Suite][suite]                  |                   [Test Coverage][coverage]                    |\n| :----------------: | :---------------------------------------------------: | :------------------------------------------------------------: |\n| [Release][release] | [![Build Status][release-suite-badge]][release-suite] | [![Coverage Status][release-coverage-badge]][release-coverage] |\n|  [Latest][latest]  |  [![Build Status][latest-suite-badge]][latest-suite]  |  [![Coverage Status][latest-coverage-badge]][latest-coverage]  |","ref":"readme.html"},{"type":"extras","title":"Changelog - Erlex","doc":"Check out the [Changelog](https://github.com/christhekeele/erlex/blob/master/CHANGELOG.md).","ref":"readme.html#changelog"},{"type":"extras","title":"Installation - Erlex","doc":"The package can be installed from Hex by adding `erlex` to your list\nof dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:erlex, \"~> 0.2\"},\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Erlex","doc":"Invoke `Erlex.pretty_print/1` with the input string.\n\n```elixir\niex> str = ~S\"('Elixir.Plug.Conn':t(),binary() | atom(),'Elixir.Keyword':t() | map()) -> 'Elixir.Plug.Conn':t()\"\niex> Erlex.pretty_print(str)\n(Plug.Conn.t(), binary() | atom(), Keyword.t() | map()) :: Plug.Conn.t()\n```\n\nWhile the lion's share of the work is done via invoking\n`Erlex.pretty_print/1`, other higher order functions exist for further\nformatting certain messages by running through the Elixir formatter.\nBecause we know the previous example is a type, we can invoke the\n`Erlex.pretty_print_contract/1` function, which would format that\nappropriately for very long lines.\n\n```elixir\niex> str = ~S\"('Elixir.Plug.Conn':t(),binary() | atom(),'Elixir.Keyword':t() | map(), map() | atom(), non_neg_integer(), binary(), binary(), binary(), binary(), binary()) -> 'Elixir.Plug.Conn':t()\"\niex> Erlex.pretty_print_contract(str)\n(\n  Plug.Conn.t(),\n  binary() | atom(),\n  Keyword.t() | map(),\n  map() | atom(),\n  non_neg_integer(),\n  binary(),\n  binary(),\n  binary(),\n  binary(),\n  binary()\n) :: Plug.Conn.t()\n```","ref":"readme.html#usage"},{"type":"extras","title":"Contributing - Erlex","doc":"We welcome contributions of all kinds! To get started, click [here](https://github.com/christhekeele/erlex/blob/master/CONTRIBUTING.md).","ref":"readme.html#contributing"},{"type":"extras","title":"Code of Conduct - Erlex","doc":"Be sure to read and follow the [code of conduct](https://github.com/christhekeele/erlex/blob/master/code-of-conduct.md).\n\n<!-- LINKS & IMAGES -->\n\n<!-- Hex -->\n\n[hex-pm]: https://hex.pm\n[hex-pm-package]: https://hex.pm/packages/erlex\n[hex-pm-versions]: https://hex.pm/packages/erlex/versions\n[hex-pm-version-badge]: https://img.shields.io/hexpm/v/erlex.svg?cacheSeconds=86400&style=flat-square\n[hex-pm-downloads-badge]: https://img.shields.io/hexpm/dt/erlex.svg?cacheSeconds=86400&style=flat-square\n[hex-pm-license-badge]: https://img.shields.io/hexpm/l/erlex.svg?cacheSeconds=86400&style=flat-square\n\n<!-- Docs -->\n\n[docs]: https://hexdocs.pm/erlex/index.html\n[docs-guides]: https://hexdocs.pm/erlex/usage.html#content\n[docs-badge]: https://img.shields.io/badge/documentation-online-purple?cacheSeconds=86400&style=flat-square\n\n<!-- Deps -->\n\n[deps]: https://hex.pm/packages/erlex\n[deps-badge]: https://img.shields.io/badge/dependencies-0-blue?cacheSeconds=86400&style=flat-square\n\n<!-- Benchmarks -->\n\n[benchmarks]: https://christhekeele.github.io/erlex/bench\n[benchmarks-badge]: https://img.shields.io/badge/benchmarks-online-2ab8b5?cacheSeconds=86400&style=flat-square\n\n<!-- Contributors -->\n\n[contributors]: https://hexdocs.pm/erlex/contributors.html\n[contributors-badge]: https://img.shields.io/badge/contributors-%F0%9F%92%9C-lightgrey\n\n<!-- Status -->\n\n[suite]: https://github.com/christhekeele/erlex/actions/workflows/test-suite.yml?query=workflow%3A%22Test+Suite%22\n[coverage]: https://coveralls.io/github/christhekeele/erlex\n\n<!-- Release Status -->\n\n[release]: https://github.com/christhekeele/erlex/tree/release\n[release-suite]: https://github.com/christhekeele/erlex/actions/workflows/test-suite.yml?query=workflow%3A%22Test+Suite%22+branch%3Arelease\n[release-suite-badge]: https://img.shields.io/github/actions/workflow/status/christhekeele/erlex/test-suite.yml?branch=release&cacheSeconds=86400&style=flat-square\n[release-coverage]: https://coveralls.io/github/christhekeele/erlex?branch=release\n[release-coverage-badge]: https://img.shields.io/coverallsCoverage/github/christhekeele/erlex?branch=release&cacheSeconds=86400&style=flat-square\n\n<!-- Latest Status -->\n\n[latest]: https://github.com/christhekeele/erlex/tree/latest\n[latest-suite]: https://github.com/christhekeele/erlex/actions/workflows/test-suite.yml?query=workflow%3A%22Test+Suite%22+branch%3Alatest\n[latest-suite-badge]: https://img.shields.io/github/actions/workflow/status/christhekeele/erlex/test-suite.yml?branch=latest&cacheSeconds=86400&style=flat-square\n[latest-coverage]: https://coveralls.io/github/christhekeele/erlex?branch=latest\n[latest-coverage-badge]: https://img.shields.io/coverallsCoverage/github/christhekeele/erlex?branch=latest&cacheSeconds=86400&style=flat-square\n\n<!-- Other -->\n\n[changelog]: https://hexdocs.pm/erlex/changelog.html\n[test-matrix]: https://github.com/christhekeele/erlex/actions/workflows/test-matrix.yml\n[test-edge]: https://github.com/christhekeele/erlex/actions/workflows/test-edge.yml\n[contributing]: https://hexdocs.pm/erlex/contributing.html\n[apache-2-license]: https://choosealicense.com/licenses/apache-2.0/","ref":"readme.html#code-of-conduct"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,49]}}